@@ -18,16 +18,22 @@ mainWindow::mainWindow()
 	//QAction *noSave= new QAction(tr("&Quit without saving"), this);
 	QAction *openFile= new QAction(tr("&Open"), this);
 	QAction *newList= new QAction(tr("&New"), this);
+	showAllAction = new QAction(tr("&Show all items"), this);
+	hideCheckedAction = new QAction(tr("&Hide checked items"), this);
 	
 	menu->addAction(newList);
 	//menu->addAction(noSave);
 	menu->addAction(openFile);
+	menu->addAction(showAllAction );
+	menu->addAction(hideCheckedAction );
 	menu->addAction(help);
 	
 	connect(help, SIGNAL(triggered()), this , SLOT(help()));
 	//connect(noSave, SIGNAL(triggered()), this , SLOT(noSave()));
 	connect(openFile, SIGNAL(triggered()), this , SLOT(openFile()));
 	connect(newList, SIGNAL(triggered()), this , SLOT(newList()));
+	connect(showAllAction , SIGNAL(triggered()), this , SLOT(showAll()));
+	connect(hideCheckedAction , SIGNAL(triggered()), this , SLOT(hideChecked()));
 	
 	
 	setCentralWidget(new QStackedWidget());
@@ -57,6 +63,7 @@ mainWindow::mainWindow()
 	static_cast<QStackedWidget*>(centralWidget())->setCurrentIndex(1);
 	load();
 	autoOrient();
+	qDebug() << "Started.";
 }
 
 void mainWindow::autoOrient()
@@ -119,6 +126,9 @@ void mainWindow::goPortrait()
 	
 	// Doing this after creating the buttons on purpose. See http://doc.qt.nokia.com/latest/qscrollarea.html#setWidget
 	portrait->setWidget(buttonPile);
+	
+	showAllAction->setEnabled(false);
+	hideCheckedAction->setEnabled(true);
 }
 
 void mainWindow::goLandscape()
@@ -154,6 +164,9 @@ void mainWindow::goLandscape()
 	delete portrait->widget();
 	
 	static_cast<QStackedWidget*>(centralWidget())->setCurrentIndex(1);
+	
+	showAllAction->setEnabled(false);
+	hideCheckedAction->setEnabled(false);
 }
 
 void mainWindow::readSettings()
@@ -180,20 +193,21 @@ void mainWindow::help()
 			"<p>Close the keyboard to return to portrait mode. In portrait mode, tap an item to check or uncheck it.</p>"
 			"<h1>Saving</h1>"
 			"<p>By default, the open list is automatically saved when quitting. "
-			"If you have accidentally opened a file you do not wish to modify, you can avoid saving it by opening another file."
+			"If you have accidentally opened a file you do not wish to modify, you can avoid saving it by opening another file. "
 			"(Simply opening and saving a file may alter whitespace).</p>"
-			"<p>When creating a new list or opening an existing list, you will be asked if you want to save the current list first.</p>");
+			"<p>When creating a new list or opening an existing list, you will be asked if you want to save the current list first.</p>"
+			"<h1>Hiding checked items</h1>"
+			"<p>You can use the \"Hide checked items\" menu button to temporarily hide checked-off items. "
+			"They can be restored by  pressing the \"Show all items\" menu button.</p>");
 	label->setWordWrap(true);
 	QScrollArea *helpWindow = new QScrollArea(this);
 	helpWindow->setWidget(label);
 	helpWindow->setWidgetResizable(true);
 	helpWindow->setWindowTitle("Checklist help");
-	//helpWindow->setStyleSheet("Font-size: 30pt; margin: 2px");
-	//helpWindow->setAlignment(Qt::AlignTop | Qt::AlignLeft);
+	helpWindow->setStyleSheet("margin: 5px");
 	helpWindow->setAttribute(Qt::WA_Maemo5StackedWindow);
 	helpWindow->setWindowFlags(Qt::Window);
 	helpWindow->show();
-	// Gotta fix the width somehow, otherwise, good.
 }
 
 // void mainWindow::noSave()
@@ -319,3 +333,27 @@ void mainWindow::newList()
 		autoOrient();
 	}
 }
+
+void mainWindow::hideChecked()
+{
+	strikeOutButton *button;
+	// Find the layout again
+	QLayout *buttonLayout = portrait->widget()->layout();
+	for (int i = 0; i < buttonLayout->count()-1; i++) {
+		button = qobject_cast<strikeOutButton*>(buttonLayout->itemAt(i)->widget());
+		if (button->font().strikeOut()==1)
+			button->hide();
+	}
+	showAllAction->setEnabled(true);
+}
+void mainWindow::showAll()
+{
+	strikeOutButton *button;
+	// Find the layout again
+	QLayout *buttonLayout = portrait->widget()->layout();
+	for (int i = 0; i < buttonLayout->count()-1; i++) {
+		button = qobject_cast<strikeOutButton*>(buttonLayout->itemAt(i)->widget());
+		button->show();
+	}
+	showAllAction->setEnabled(false);
+}
