@@ -4,6 +4,7 @@
 #include <QMainWindow>
 #include <QPlainTextEdit>
 #include <QScrollArea>
+#include <QAction>
 
 class mainWindow : public QMainWindow
 {
@@ -17,7 +18,11 @@ private slots:
 	//void noSave();
 	void openFile();
 	void newList();
+	void hideChecked();
+	void showAll();
 private:
+	QAction* hideCheckedAction;
+	QAction* showAllAction;
 	QScrollArea *portrait;
 	QPlainTextEdit *landscape;
 	void goLandscape(void);
